# KYAML

<aside class="warning">
⚠️ This is entirely experimental at this point and I'm not sure if I'm going to
continue development of this tool.
</aside>

Utility to manipulate Kubernetes YAML files.

# Installation

If you don't use `pipsi`, you're missing out.
Here are [installation instructions](https://github.com/mitsuhiko/pipsi#readme).

Simply run:

    $ pipsi install .

# Usage

To use it:

    $ kyaml --help

The only thing it does right now is split a single combined Kubernetes YAML
manifest file into individual manifest files. More features may be added in the
future -- or not. 🤷‍♂️
